.. _installation:

Installation
============

.. currentmodule:: flask_restful

Install Flask-RESTful with ``pip`` ::

    pip install flask-restful


The development version can be downloaded from `its page at GitHub
<https://github.com/flask-restful/flask-restful>`_. ::

    git clone https://github.com/flask-restful/flask-restful.git
    cd flask-restful
    python setup.py develop


Flask-RESTful has the following dependencies (which will be automatically
installed if you use ``pip``):


* `Flask <http://flask.pocoo.org>`_ version 0.8 or greater

Flask-RESTful requires Python version 2.6, 2.7, 3.3, 3.4, 3.5 or 3.6.
